@@ -96,7 +96,7 @@ summary.ppmc <- function(object, discFUN, dist = c("obs","sim"),
                                            round(prob*100, 2),
                                            "% credible intervals")
                                   }, ""),
-                                  " for the posterior ",
+                                  "\n for the posterior ",
                                   if (dist == "sim") "predictive ",
                                   "distribution of ",
                                   if (dist == "obs") "realized ",
@@ -105,7 +105,7 @@ summary.ppmc <- function(object, discFUN, dist = c("obs","sim"),
                                   if (dist == "sim") {
                                     "data simulated from the posterior, "
                                   } else "data, ",
-                                  "along with posterior predictive p values ",
+                                  "\n along with posterior predictive p values ",
                                   "to test hypotheses in either direction:\n",
                                   sep = "")
   } else {
@@ -143,7 +143,7 @@ summary.ppmc <- function(object, discFUN, dist = c("obs","sim"),
                                                round(prob*100, 2),
                                                "% credible intervals")
                                       }, ""),
-                                      " for the posterior ",
+                                      "\n for the posterior ",
                                       if (dist == "sim") "predictive ",
                                       "distribution of ",
                                       if (dist == "obs") "realized ",
@@ -152,7 +152,7 @@ summary.ppmc <- function(object, discFUN, dist = c("obs","sim"),
                                       if (dist == "sim") {
                                         "data simulated from the posterior, "
                                       } else "data, ",
-                                      "along with posterior predictive p values ",
+                                      "\n along with posterior predictive p values ",
                                       "to test hypotheses in either direction:\n",
                                       sep = "")
 
@@ -184,7 +184,7 @@ summary.ppmc <- function(object, discFUN, dist = c("obs","sim"),
             attr(out[[mm]], "header") <- paste0("Highest posterior density (HPD) ",
                                                 round(prob*100, 2), "% ",
                                                 toupper(names(out)[[mm]]),
-                                                " credible-interval limits for the posterior ",
+                                                " credible-interval limits for the\n posterior ",
                                                 if (dist == "sim") "predictive ",
                                                 "distribution of ",
                                                 if (dist == "obs") "realized ",
@@ -576,12 +576,12 @@ ppmc <- function(object, thin = 1, fit.measures = c("srmr","chisq"),
   }
 
   ## differentiate between multiple possible chisq stats
-  if (length(fit.measures) == 1L & blavInspect(object, "categorical")) {
+  if (length(fit.measures) == 1L) {
     if (fit.measures == "chisq") {
-      ## add another so that the dwls chisq from lavaan is used
+      ## add another so that the chisq from lavaan is used
       ## (due to the way blav_model_loglik is structured)
       fit.measures <- c("chisq", "chisq.scaled")
-    } else if (fit.measures == "marglogl") {
+    } else if (fit.measures == "marglogl" & blavInspect(object, "categorical")) {
       ## approximate the marginal lrt
       fit.measures <- "chisq"
     }
